@@ -1,30 +1,32 @@
-(******************************************************************************)
-(*                                                                            *)
-(*     The Alt-Ergo theorem prover                                            *)
-(*     Copyright (C) 2006-2013                                                *)
-(*                                                                            *)
-(*     Sylvain Conchon                                                        *)
-(*     Evelyne Contejean                                                      *)
-(*                                                                            *)
-(*     Francois Bobot                                                         *)
-(*     Mohamed Iguernelala                                                    *)
-(*     Stephane Lescuyer                                                      *)
-(*     Alain Mebsout                                                          *)
-(*                                                                            *)
-(*     CNRS - INRIA - Universite Paris Sud                                    *)
-(*                                                                            *)
-(*     This file is distributed under the terms of the Apache Software        *)
-(*     License version 2.0                                                    *)
-(*                                                                            *)
-(*  ------------------------------------------------------------------------  *)
-(*                                                                            *)
-(*     Alt-Ergo: The SMT Solver For Software Verification                     *)
-(*     Copyright (C) 2013-2018 --- OCamlPro SAS                               *)
-(*                                                                            *)
-(*     This file is distributed under the terms of the Apache Software        *)
-(*     License version 2.0                                                    *)
-(*                                                                            *)
-(******************************************************************************)
+(**************************************************************************)
+(*                                                                        *)
+(*     Alt-Ergo: The SMT Solver For Software Verification                 *)
+(*     Copyright (C) 2013-2023 --- OCamlPro SAS                           *)
+(*                                                                        *)
+(*     This file is distributed under the terms of OCamlPro               *)
+(*     Non-Commercial Purpose License, version 1.                         *)
+(*                                                                        *)
+(*     As an exception, Alt-Ergo Club members at the Gold level can       *)
+(*     use this file under the terms of the Apache Software License       *)
+(*     version 2.0.                                                       *)
+(*                                                                        *)
+(*     ---------------------------------------------------------------    *)
+(*                                                                        *)
+(*     The Alt-Ergo theorem prover                                        *)
+(*                                                                        *)
+(*     Sylvain Conchon, Evelyne Contejean, Francois Bobot                 *)
+(*     Mohamed Iguernelala, Stephane Lescuyer, Alain Mebsout              *)
+(*                                                                        *)
+(*     CNRS - INRIA - Universite Paris Sud                                *)
+(*                                                                        *)
+(*     Until 2013, some parts of this code were released under            *)
+(*     the Apache Software License version 2.0.                           *)
+(*                                                                        *)
+(*     ---------------------------------------------------------------    *)
+(*                                                                        *)
+(*     More details can be found in the directory licenses/               *)
+(*                                                                        *)
+(**************************************************************************)
 
 open AltErgoLib
 open AltErgoParsers
@@ -693,8 +695,12 @@ and axiom_callback t env ~origin:y z i =
           let menu = GMenu.menu () in
           let menu_item = GMenu.menu_item ~packing:menu#append () in
           let vbox = GPack.hbox ~packing:menu_item#add () in
-          let _ = GMisc.label ~text:"Instanciate axiom ..." ~packing:vbox#add () in
-          let _ = GMisc.image ~stock:`ADD ~icon_size:`MENU ~packing:vbox#add () in
+          let _ =
+            GMisc.label ~text:"Instanciate axiom ..." ~packing:vbox#add ()
+          in
+          let _ =
+            GMisc.image ~stock:`ADD ~icon_size:`MENU ~packing:vbox#add ()
+          in
           ignore(menu_item#connect#activate
                    ~callback:(popup_axiom t env offset));
           menu#popup ~button:3 ~time:(GdkEvent.Button.time z);
@@ -784,7 +790,7 @@ and popup_trigger t qid env (sbuf:sbuffer) offset () =
       ~packing:pop_w#vbox#add ()
   in
   let tv1 = GSourceView3.source_view ~source_buffer:buf1 ~packing:(sw1#add)
-       ~show_line_numbers:true ~wrap_mode:`CHAR()
+      ~show_line_numbers:true ~wrap_mode:`CHAR()
   in
   let _ = tv1#misc#modify_font font in
   let _ = tv1#set_editable true in
@@ -822,8 +828,12 @@ and triggers_callback t qid env sbuf ~origin:y z i =
           let menu = GMenu.menu () in
           let menu_item = GMenu.menu_item ~packing:menu#append () in
           let vbox = GPack.hbox ~packing:menu_item#add () in
-          let _ = GMisc.label ~text:"Add trigger(s) ..." ~packing:vbox#add () in
-          let _ = GMisc.image ~stock:`ADD ~icon_size:`MENU ~packing:vbox#add () in    
+          let _ =
+            GMisc.label ~text:"Add trigger(s) ..." ~packing:vbox#add ()
+          in
+          let _ =
+            GMisc.image ~stock:`ADD ~icon_size:`MENU ~packing:vbox#add ()
+          in
           ignore(menu_item#connect#activate
                    ~callback:(popup_trigger t qid env sbuf offset));
           menu#popup ~button:3 ~time:(GdkEvent.Button.time z);
@@ -971,15 +981,18 @@ let show_used_lemmas env expl =
   clear_used_lemmas_tags env;
   let max_mul = MTag.fold (fun _ m acc -> max acc m) ftags 0 in
   let green_0 =
-    Gdk.Color.color_parse (Gui_util.dec_to_hex_color (65535*3/4) 65535 (65535*3/4))
+    Gdk.Color.color_parse
+      (Gui_util.dec_to_hex_color (65535*3/4) 65535 (65535*3/4))
   in
   List.iter (fun t -> t#set_property (`BACKGROUND_GDK green_0)) atags;
   MTag.iter (fun t m ->
       let perc = ((max_mul - m) * 65535) / max_mul in
       let green_n = Gdk.Color.color_parse
-          (Gui_util.dec_to_hex_color (perc*1/2) ((perc + 2*65535) /3) (perc*1/2)) in
+          (Gui_util.dec_to_hex_color (perc*1/2)
+             ((perc + 2*65535) /3) (perc*1/2))
+      in
       t#set_property (`BACKGROUND_GDK green_n)) ftags;
-  env.proof_tags <- ftags; 
+  env.proof_tags <- ftags;
   env.proof_toptags <- atags
 
 
