@@ -1,30 +1,32 @@
-(******************************************************************************)
-(*                                                                            *)
-(*     The Alt-Ergo theorem prover                                            *)
-(*     Copyright (C) 2006-2013                                                *)
-(*                                                                            *)
-(*     Sylvain Conchon                                                        *)
-(*     Evelyne Contejean                                                      *)
-(*                                                                            *)
-(*     Francois Bobot                                                         *)
-(*     Mohamed Iguernelala                                                    *)
-(*     Stephane Lescuyer                                                      *)
-(*     Alain Mebsout                                                          *)
-(*                                                                            *)
-(*     CNRS - INRIA - Universite Paris Sud                                    *)
-(*                                                                            *)
-(*     This file is distributed under the terms of the Apache Software        *)
-(*     License version 2.0                                                    *)
-(*                                                                            *)
-(*  ------------------------------------------------------------------------  *)
-(*                                                                            *)
-(*     Alt-Ergo: The SMT Solver For Software Verification                     *)
-(*     Copyright (C) 2013-2018 --- OCamlPro SAS                               *)
-(*                                                                            *)
-(*     This file is distributed under the terms of the Apache Software        *)
-(*     License version 2.0                                                    *)
-(*                                                                            *)
-(******************************************************************************)
+(**************************************************************************)
+(*                                                                        *)
+(*     Alt-Ergo: The SMT Solver For Software Verification                 *)
+(*     Copyright (C) 2013-2023 --- OCamlPro SAS                           *)
+(*                                                                        *)
+(*     This file is distributed under the terms of OCamlPro               *)
+(*     Non-Commercial Purpose License, version 1.                         *)
+(*                                                                        *)
+(*     As an exception, Alt-Ergo Club members at the Gold level can       *)
+(*     use this file under the terms of the Apache Software License       *)
+(*     version 2.0.                                                       *)
+(*                                                                        *)
+(*     ---------------------------------------------------------------    *)
+(*                                                                        *)
+(*     The Alt-Ergo theorem prover                                        *)
+(*                                                                        *)
+(*     Sylvain Conchon, Evelyne Contejean, Francois Bobot                 *)
+(*     Mohamed Iguernelala, Stephane Lescuyer, Alain Mebsout              *)
+(*                                                                        *)
+(*     CNRS - INRIA - Universite Paris Sud                                *)
+(*                                                                        *)
+(*     Until 2013, some parts of this code were released under            *)
+(*     the Apache Software License version 2.0.                           *)
+(*                                                                        *)
+(*     ---------------------------------------------------------------    *)
+(*                                                                        *)
+(*     More details can be found in the directory licenses/               *)
+(*                                                                        *)
+(**************************************************************************)
 
 open Format
 open Options
@@ -448,7 +450,7 @@ let generic_find ?(only_inf=false) xp env =
        interval, the function will raise, in order to let its caller know the
        interval is not consistent/reachable/satisfiable.
        This interacts badly with callers who only care about the lower bound,
-       as these callers do not catch the inconsisten exception, and this can
+       as these callers do not catch the inconsistent exception, and this can
        lead to the solver returning Unsat/Valid even when it is incorrect to
        do so. (see issues #460 #340, and PRs #342 and #465). *)
     let ip =
@@ -494,11 +496,18 @@ let generic_add x j use is_mon env =
 module Debug = struct
   open Printer
 
-  let assume a expl =
+  let add p =
+    if get_debug_fm () then
+      print_dbg
+        ~module_name:"IntervalCalculus" ~function_name:"add"
+        "@[<v 2>New polynome added: %a]" P.print p
+
+  let assume ~query a expl =
     if get_debug_fm () then
       print_dbg
         ~module_name:"IntervalCalculus" ~function_name:"assume"
-        "@[<v 2>We assume: %a@,explanations: %a@]"
+        "@[<v 2>%s We assume: %a@,explanations: %a@]"
+        (if query then "[query]" else "")
         LR.print (LR.make a)
         Explanation.print expl
 
@@ -675,17 +684,21 @@ let mult_bornes_vars vars env ty =
     The monomes are supposed to be already added in env **)
 let intervals_from_monomes ?(monomes_inited=true) env p =
   let pl, v = P.to_list p in
-  List.fold_left
-    (fun i (a, x) ->
-       let i_x, _  =
-         try MX.n_find x env.monomes
-         with Not_found ->
-           if monomes_inited then assert false;
-           I.undefined (X.type_info x), SX.empty
-       in
-       I.add (I.scale a i_x) i
-    ) (I.point v (P.type_info p) Explanation.empty) pl
-
+  (* in the case of integer polynomes, ensure that we only round once
+     at the end, and not at every add/scale operation on intervals. *)
+  let rational_interval =
+    List.fold_left
+      (fun i (a, x) ->
+         let i_x, _  =
+           try MX.n_find x env.monomes
+           with Not_found ->
+             assert (not monomes_inited);
+             I.undefined (X.type_info x), SX.empty
+         in
+         I.add (I.scale a (I.coerce Ty.Treal i_x)) i
+      ) (I.point v Ty.Treal Explanation.empty) pl
+  in
+  I.coerce (P.type_info p) rational_interval
 
 (* because, it's not sufficient to look in the interval that corresponds to
    the normalized form of p ... *)
@@ -721,8 +734,6 @@ and init_alien are_eq expl p (normal_p, c, d) ty use_x env =
   in
   env, i
 
-
-
 and update_monome are_eq expl use_x env x =
   let ty = X.type_info x in
   let ui, env = match  X.ac_extract x with
@@ -1493,7 +1504,25 @@ let tighten_eq_bounds env r1 r2 p1 p2 origin_eq expl =
       Debug.tighten_interval_modulo_eq_begin p1 p2;
       let i1, us1, is_mon_1 = generic_find r1 env in
       let i2, us2, is_mon_2 = generic_find r2 env in
-      let j = I.add_explanation (I.intersect i1 i2) expl in
+      (* We are assuming [origin_eq] with explanation [expl], where [origin_eq]
+       * is an equality between terms [r1] and [r2] with respective intervals
+       * [i1] and [i2].
+       *
+       * The shared interval for both [r1] and [r2] after the assumption
+       * becomes the intersection of [i1] and [i2], and must account for the
+       * additional explanation [expl] (since [origin_eq] is only valid under
+       * [expl]).
+       *
+       * [I.intersect] raises a "not consistent" exception if the two intervals
+       * are disjoint, but it does so *before* the additional explanation is
+       * added to the intervals' bounds, so we must add it explicitly in that
+       * case.
+      *)
+      let intersect i1 i2 =
+        try I.intersect i1 i2
+        with I.NotConsistent ex -> raise (I.NotConsistent (Ex.union ex expl))
+      in
+      let j = I.add_explanation (intersect i1 i2) expl in
       Debug.tighten_interval_modulo_eq_middle p1 p2 i1 i2 j;
       let impr_i1 = I.is_strict_smaller j i1 in
       let impr_i2 = I.is_strict_smaller j i2 in
@@ -1578,7 +1607,7 @@ let assume ~query env uf la =
     List.fold_left
       (fun ((env, eqs, new_ineqs, rm) as acc) (a, root, expl, orig) ->
          let a = normal_form a in
-         Debug.assume a expl;
+         Debug.assume ~query a expl;
          Steps.incr (Interval_Calculus);
          try
            match a with
@@ -1833,15 +1862,19 @@ let add =
     if E.equal t1 t2 then Some (Explanation.empty, []) else None
   in
   fun env new_uf r t ->
+    Debug.env env;
     try
       let env = {env with new_uf} in
+      let p = poly_of r in
+      Debug.add p;
       if is_num r then
-        let env = init_monomes_of_poly are_eq env
-            (poly_of r) SX.empty Explanation.empty in
+        let env =
+          init_monomes_of_poly are_eq env p SX.empty Explanation.empty
+        in
         add_used_by t r env
       else env, []
     with I.NotConsistent expl ->
-      Debug.inconsistent_interval expl ;
+      Debug.inconsistent_interval expl;
       raise (Ex.Inconsistent (expl, env.classes))
 
 (*
